Changelog
==========

1.1.0 (2020-05-04)
------------------

- Recognize simple hostname:path git URLs (GH: #3).

- Change output format to show pipeline dates and short Git commit IDs instead
  of full Git commit IDs.


1.0.1 (2020-04-29)
------------------

- Fix broken image on PyPI project page.


1.0 (2020-04-29)
----------------

- First public release
